@echo off
REM
REM File: DISTRIB.BAT
REM
REM A little batch file to make directory [envelop]\DISTRIB, where [envelop]
REM is the directory Envelop was installed to (C:\ENVELOP by default).
REM
REM Copy this file to the [envelop]\PROGRAM directory, CD to that directory,
REM and run this script to make the DISTRIB directory. If the DISTRIB
REM directory already exists, or if curren directory is not PROGRAM,
REM then this script exits with an error message.
REM
REM The [envelop]\DISTRIB directory will contain the minimal set of
REM files to support most typical Envelop applications. To distribute
REM an application to a computer that does not already have Envelop
REM installed:
REM   1) Copy the files from the DISTRIB directory (and subdir SYS too).
REM   2) Copy the application's modules (.EBO) and executable (.EXE) files.
REM   3) Ensure the files from the DISTRIB\SYS directory are copied to
REM      the SYSTEM32 (NT) or SYSTEM (95) directory on the target machine,
REM      under the Windows system directory.
REM   4) Ensure the entries from ENVELOP.REG are in the registry on
REM      the target machine. Either double-click this file from
REM      File Manager or Explorer, or run REGEDIT ENVELOP.REG.
REM   5) If your application files are not in the same directory that
REM      contains the DISTRIB files (on the target machine), then ensure
REM      that the target machine's DISTRIB directory is in the PATH.
REM
if not exist .\evstore.dll goto ERROR_NO_ENVELOP
if exist ..\DISTRIB\NUL goto ERROR_DISTRIB_EXISTS
cd ..
md distrib
copy program\ou*.dll distrib
copy program\ms*.dll distrib
copy program\ev*.dll distrib
copy program\od*.dll distrib
copy program\*.reg   distrib
copy program\*.ebo   distrib
del  distrib\evdev.dll
del  distrib\evmaged.dll
del  distrib\dbtools.ebo
del  distrib\envelop.ebo
del  distrib\evhelp.ebo
del  distrib\options.ebo

REM
REM The files copied to DISTRIB\SYS must be installed in the target
REM computer's SYSTEM32 (NT) or SYSTEM (95) directory, under the
REM Windows directory.
REM
md distrib\sys
if not "%SystemRoot%" == "" goto SYS_WINNT
if not "%windir%" == "" goto SYS_WIN95
goto ERROR_UNKNOWN_CONFIG
:SYS_WINNT
set SYSSRC=%SystemRoot%\system32
goto SYS_COPY
:SYS_WIN95
set SYSSRC=%windir%\system
:SYS_COPY
if not exist %SYSSRC%\ivsql08.dll goto ERROR_NO_SYSFILES
copy %SYSSRC%\ctl3d32.dll  distrib\sys
copy %SYSSRC%\cw3215.dll   distrib\sys
copy %SYSSRC%\odbc32.dll   distrib\sys
copy %SYSSRC%\odbccp32.dll distrib\sys
copy %SYSSRC%\ivlib.dll    distrib\sys
copy %SYSSRC%\ivsql08.dll  distrib\sys
copy %SYSSRC%\ivutl08.dll  distrib\sys
copy %SYSSRC%\ivbas08.dll  distrib\sys
copy %SYSSRC%\ivflt08.dll  distrib\sys

goto DONE

:ERROR_NO_ENVELOP
echo ERROR: Could not find PROGRAM\evstore.dll
echo Run this batch file from the directory Envelop was installed to.
goto DONE

:ERROR_DISTRIB_EXISTS
echo ERROR: Directory DISTRIB already exists. Please remove it and try again.
goto DONE

:ERROR_UNKNOWN_CONFIG
echo ERROR: Cannot determine whether your system is running WinNT or Win95.
echo        Unable to copy system files needed.
goto DONE

:ERROR_NO_SYSFILES
echo ERROR: Cannot find system files needed.
goto DONE

:DONE
